<h3>The Crystals tab</h3>

<figure>
    <img alt="" src="/help/crystal/listtab.png"/>
    <figcaption>The Crystals tab, showing a list of crystals.</figcaption>
</figure>

<p>The Crystals tab lists all associated crystals. For each crystal, the image, plate, and well, drop and crystal number
    are shown.</p>
<p> There is also a star rating beside each crystal; you can change this in the crystal's view page or in the drop viewer.
    The star rating is entirely subjective, so it's up to you what they mean. You can sort the list to bring the best-rated
    crystals to the top.</p>
<p>Click the image to open it in the Drop Viewer. Click the plate name to go to the plate. Click the well and drop details
    to go to the crystal page.</p>
